summaryrefslogtreecommitdiff
path: root/source4/libnet/libnet_vampire.c
diff options
context:
space:
mode:
authorAndrew Bartlett <abartlet@samba.org>2017-02-23 13:00:19 +1300
committerAndrew Bartlett <abartlet@samba.org>2017-02-23 11:36:21 +0100
commit7ed611143f281ecf15f69d260fd9042c443e10da (patch)
tree687471d2f8ab6f14c989c8476b63a190e57e0d23 /source4/libnet/libnet_vampire.c
parente2ba17d26af42974e5d389a3706a45fd00185875 (diff)
downloadsamba-7ed611143f281ecf15f69d260fd9042c443e10da.tar.gz
samba-tool drs replicate: Add --single-object
This may help when an object has been incorrectly locally removed from the NC or there is an urgent need to replicate a specific object (say when full replication is inoperable). Signed-off-by: Andrew Bartlett <abartlet@samba.org> Reviewed-by: Garming Sam <garming@catalyst.net.nz>
Diffstat (limited to 'source4/libnet/libnet_vampire.c')
-rw-r--r--source4/libnet/libnet_vampire.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/source4/libnet/libnet_vampire.c b/source4/libnet/libnet_vampire.c
index f74f9bb4f78..f6bcf2951a3 100644
--- a/source4/libnet/libnet_vampire.c
+++ b/source4/libnet/libnet_vampire.c
@@ -652,10 +652,10 @@ WERROR libnet_vampire_cb_store_chunk(void *private_data,
return WERR_INVALID_PARAMETER;
}
- if (req_replica_flags & DRSUAPI_DRS_CRITICAL_ONLY) {
+ if (req_replica_flags & DRSUAPI_DRS_CRITICAL_ONLY || is_exop) {
/*
* If we only replicate the critical objects
* we should not remember what we already
* got, as it is incomplete.
*/
ZERO_STRUCT(s_dsa->highwatermark);
@@ -652,10 +652,10 @@ WERROR libnet_vampire_cb_store_chunk(void *private_data,
/*
- * If we only replicate the critical objects
- * we should not remember what we already
+ * If we only replicate the critical objects, or this
+ * is an exop we should not remember what we already
* got, as it is incomplete.
*/